@@ -11,6 +11,7 @@
 #include <memory>
 #include <string>
 #include <vector>
+#include <fcitx-utils/log.h>
 #include <fcitx-utils/macros.h>
 #include "fcitxcore_export.h"
 
@@ -27,11 +28,15 @@ public:
     InputMethodGroupItem &setLayout(const std::string &layout);
     const std::string &name() const;
     const std::string &layout() const;
+    bool isKeyboard() const;
 
     std::unique_ptr<InputMethodGroupItemPrivate> d_ptr;
     FCITX_DECLARE_PRIVATE(InputMethodGroupItem);
 };
 
+LogMessageBuilder &operator<<(LogMessageBuilder &builder,
+                              const InputMethodGroupItem &groupItem);
+
 class FCITXCORE_EXPORT InputMethodGroup {
 public:
     explicit InputMethodGroup(const std::string &name);
@@ -44,7 +49,7 @@ public:
     const std::vector<InputMethodGroupItem> &inputMethodList() const;
     const std::string &defaultInputMethod() const;
     void setDefaultInputMethod(const std::string &im);
-    const std::string &layoutFor(const std::string &im);
+    const std::string &layoutFor(const std::string &im) const;
 
 private:
     std::unique_ptr<InputMethodGroupPrivate> d_ptr;
